@@ -109,7 +109,7 @@ def print_results(results):
         else str("${:,}".format(x))
         for x in gains
     ]
-    if net_worth[0] > 0:
+    if (net_worth[0] - gains[0]) > 0:
         percent = 100 * gains[0] / (net_worth[0] - gains[0])
         yoy_percent = (
             color.RED
@@ -303,25 +303,15 @@ def extract_financial_document(
                 page_paths, resize=resize
             )
         except:
-            import time
-
-            time.sleep(2)
             try:
-                logging.info("Switch resizing mechanism")
+                logging.info("Switch resizing again")
                 resize = False if resize else True
-                document_structure, check_count = extract_contours_from_page(
-                    page_paths, resize=True
-                )
+                (
+                    document_structure,
+                    check_count,
+                ) = extract_contours_from_page(page_paths, resize=resize)
             except:
-                try:
-                    logging.info("Switch resizing again")
-                    resize = False if resize else True
-                    (
-                        document_structure,
-                        check_count,
-                    ) = extract_contours_from_page(page_paths, resize=resize)
-                except:
-                    return {"success": False, "msg": CheckboxesNotFound}
+                return {"success": False, "msg": CheckboxesNotFound}
 
         if check_count < 8:
             logging.warning("Failed to extract document structure")
